/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */
package com.liferay.test;

import java.io.IOException;
import java.io.PrintWriter;
import java.lang.reflect.Method;

import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletSession;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import javax.servlet.http.HttpServletRequest;

import com.liferay.portal.util.PortalUtil;


/**
 * @author  Neil Griffin
 */
public class TestPortlet extends GenericPortlet {

	@Override
	protected void doView(RenderRequest renderRequest, RenderResponse renderResponse) throws PortletException,
		IOException {

		try {
			PrintWriter writer = renderResponse.getWriter();
			writer.write("<p>");
			writer.write("In order to test LPS-40115, two instances of this portlet must be put on a portal page.");
			writer.write("</p>");

			PortletSession portletSession = renderRequest.getPortletSession();
			Method getHttpSessionMethod = portletSession.getClass().getMethod("getHttpSession", new Class[] {});
			Object httpSession = getHttpSessionMethod.invoke(portletSession, new Object[] {});
			int hashCode = httpSession.hashCode();

			if (hashCode == 0) {
				writer.write("<p style=\"color: red;\">");
				writer.write("LPS-40115 is still broken because <strong>SharedSessionWrapper._portalSession</strong> and ");
				writer.write("<strong>SharedSessionWrapper_.portletSession</strong> are THE SAME.<br /><br />");
				writer.write("Try adding ?p_p_parallel=0 to the URL and see if you get different results.");
				writer.write("</p>");
			}
			else {
				String currentURL = PortalUtil.getCurrentURL(renderRequest);
				int pos = currentURL.indexOf("p_p_parallel=0");
				if (pos > 0) {
					writer.write("<p>");
					writer.write("The portalSession and portletSession are different. <strong>But LPS-40115 might still be broken ");
					writer.write("since p_p_parallel=0 was specified on the URL.</strong>");
					writer.write("</p>");
				}
				else {
					writer.write("<p>");
					writer.write("The portalSession and portletSession are different. If two or more instances of this portlet ");
					writer.write("are on this portal page, then LPS-40115 is fixed.");
					writer.write("</p>");
				}
			}

		}
		catch (Exception e) {
			e.printStackTrace();
			throw new IOException(e.getMessage());
		}
	}
}
